"""Prep __main__.py."""
# pylint: disable=invalid-name
import logging
from pathlib import Path
from typing import List, Optional

import typer
from rich.logging import RichHandler
from set_loglevel import set_loglevel

from json_de2zh import __version__, json_de2zh

logging.basicConfig(
    handlers=[RichHandler()],
    format="%(message)s",
    datefmt="%y%m%d %H:%M:%S",
)
_ = ".".join(Path(__file__).with_suffix("").parts[-2:])
logger = logging.getLogger(_)
logger.setLevel(set_loglevel())

# logger.info("__name__: %s", __name__)
# logger.info("__file__: %s", __file__)
logger.debug("logger for this file: %s", _)
# logger.info("logger for this file: %s ", _)
logger.info("set_loglevel(): %s ", set_loglevel())


app = typer.Typer(
    name="json-de2zh",
    add_completion=False,
    help="json-de2zh help",
)


def _version_callback(value: bool) -> None:
    if value:
        typer.echo(f"{app.info.name} v.{__version__} -- ...")
        raise typer.Exit()


@app.command()
def main(
    words: Optional[List[str]] = typer.Argument(
        None,
        metavar="word1 [word2]...",
        help="files (absolute or relative paths) to be aligned; if only one file is specified, the -s flag must be used to signal it's an english/chinese mixed text file and needs to be separated.",
    ),
    version: Optional[bool] = typer.Option(  # pylint: disable=(unused-argument
        None,
        "--version",
        "-v",
        "-V",
        help="Show version info and exit.",
        callback=_version_callback,
        is_eager=True,
    ),
):
    """Look up words from json/mdx_dict."""
    logger.debug("collecting inputs")
    logger.debug("words: %s", words)
    if words is None:
        words = []
    for word in words:
        print(word, json_de2zh(word))


if __name__ == "__main__":
    app()



"""Obtain the lemmatize and split a german sentence.

# sentences = nltk.sent_tokenize(text,language='german')

sentences = [elm.strip() for elm in text.splitlines() if elm.strip()]

tokenized_sent = nltk.tokenize.word_tokenize(sentences[23],language='german')
print(tokenized_sent)

pip install git+https://github.com/dtuggener/CharSplit.git
from charsplit import Splitter
splitter = Splitter()
splitter.split_compound("Autobahnraststätte")

splitter.split_compound("Behördenangaben")
# [(1.007164301616347, 'Behörden', 'Angaben'),
# (-0.7395413338811989, 'Behörde', 'Nangaben'),
# (-0.889745566692367, 'Behördenan', 'Gaben'),

slow:  4739 words (words = Path("data/sternstunden04-de.txt").read_text('utf8').split())
%time lemma_data = tagger.tag_sent(words, taglevel=1)
20s

%time spl_data = [split_compound(w) for w in words]
CPU times: total: 656 ms
Wall time: 653 ms

[elm for elm in spl_data if elm[0][0] > .85]

"""
# pylint: disable=invalid-name
import re
import sys
from typing import List, Union
from unicodedata import category

# from charsplit import Splitter
from split_words import Splitter

split_comp = Splitter().split_compound

punctuation = "".join(
    chr(i) for i in range(sys.maxunicode) if category(chr(i)).startswith("P")
)
patt = re.compile(rf"[{re.escape(punctuation)}]")


def split_compound(
    sents_: Union[List[str], str],
) -> List[List[str]]:
    """Lemmatize and split German text."""
    if isinstance(sents_, str):
        sents = [sents_]
    else:
        sents = sents_[:]

    # remove punctuation: replace with " "
    sents = [patt.sub(" ", elm) for elm in sents]

    res = []
    for sent in sents:
        words = sent.split()
        words_ = []
        for word in words:
            # [elm if (split_compound(elm)[0][0] < 0.85) else split_compound(elm)[0][1:] for elm in sent.split()]
            _ = split_comp(word)

            # (0.8640814727771249, 'Regional', 'Gouverneur')
            # logger.debug("lemm: %s, split_compound(lemma)[0]: %s", lemma, _[0])

            if _[0][0] > 0.85:
                words_.extend(_[0][1:])
            else:
                words_.append(word)

        res.append(words_)

    # return [["sein", "Angabe"]]
    return res



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['json_de2zh']

package_data = \
{'': ['*']}

install_requires = \
['alive-progress>=2.4.1,<3.0.0',
 'cmat2aset>=0.1.0-alpha.7,<0.2.0',
 'fast-scores>=0.1.2,<0.2.0',
 'fastlid>=0.1.7,<0.2.0',
 'icecream>=2.1.1,<3.0.0',
 'install>=1.3.5,<2.0.0',
 'joblib>=1.1.0,<2.0.0',
 'nltk>=3.7,<4.0',
 'numpy>=1.22.3,<2.0.0',
 'rich>=12.4.1,<13.0.0',
 'set-loglevel>=0.1.2,<0.2.0',
 'simplemma==0.3.0',
 'sklearn>=0.0,<0.1',
 'split-words>=0.1.2,<0.2.0',
 'typer>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['json-de2zh = json_de2zh.__main__:app']}

setup_kwargs = {
    'name': 'json-de2zh',
    'version': '0.1.1a0',
    'description': 'pack_name descr ',
    'long_description': '# json-de2zh\n[![pytest](https://github.com/ffreemt/json-de2zh/actions/workflows/routine-tests.yml/badge.svg)](https://github.com/ffreemt/json-de2zh/actions)[![python](https://img.shields.io/static/v1?label=python+&message=3.8%2B&color=blue)](https://www.python.org/downloads/)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/json-de2zh.svg)](https://badge.fury.io/py/json-de2zh)\n\njson-de2zh gen_cmat based on fundset (stardict)\n\n## Install it\n\n```shell\npip install git+https://github.com/ffreemt/json-de2zh\n# poetry add git+https://github.com/ffreemt/json-de2zh\n# git clone https://github.com/ffreemt/json-de2zh && cd json-de2zh\n```\n\n## Use it\n```python\nfrom json_de2zh import json_de2zh\n\n```\n',
    'author': 'ffreemt',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ffreemt/json-de2zh',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8.3,<4.0.0',
}


setup(**setup_kwargs)



"""Translate english to chinese via a dict."""
import copy
from typing import List, Union

# from word_tr import word_tr
from .json_de2zh import json_de2zh


# fmt: off
def de2zh(
        text: Union[str, List[List[str]]],
) -> List[str]:
    # fmt: on
    """Translate english to chinese via a dict.

    Args
        text: to translate, list of list of str

    Returns
        res: list of str
    """
    res = copy.deepcopy(text)
    if isinstance(text, str):
        res = [text.split()]

    # if res and isinstance(res[0], str):
        # res = [line.lower().split() for line in res]

    res = ["".join([json_de2zh(word) for word in line]) for line in res]

    return res
